@@ -1,10 +1,11 @@
 // crate::util::config
 // Configures files on start-up
 
-use std::env;
 use std::io::Read;
 use std::fs;
 
+use super::error::{BoronError, throw};
+
 pub struct BinConfig {
     pub program: Vec<u8>,
 }
@@ -14,69 +15,60 @@ pub struct TxtConfig {
     pub name: String,
 }
 
-pub fn binconfigure() -> BinConfig {
-    let args: Vec<String> = env::args().collect();
-    let name: String = args[1].clone();
-
-    // file must be mutable here as it is being read later in the program
-    // We also pass &name rather than name to prevent changing the parent scope of name
-    let mut file = fs::File::open(&name).expect("Could not find filename");
-    let metadata = fs::metadata(&name).expect("Unable to read metadata");
-
-    let mut buffer = vec![0u8; metadata.len() as usize];
-    // We pass &mut buffer to prevent changing the scope of buffer while still permitting modification
-    file.read(&mut buffer).expect("Buffer overflow");
-
-    BinConfig {program: buffer}
-}
-
-pub fn binconfigure_from_filename(filename: &str) -> BinConfig {
+pub fn binconfigure(filename: &str) -> BinConfig {
     let name: String = String::from(filename);
 
     // file must be mutable here as it is being read later in the program
     // We also pass &name rather than name to prevent changing the parent scope of name
-    let mut file = fs::File::open(&name).expect("Could not find filename");
+    let mut file = match fs::File::open(&name) {
+        Ok(f) => f,
+        _ => {
+            throw(BoronError::FileNotFoundError);
+            return BinConfig {program: Vec::new()};
+        },
+    };
     let metadata = fs::metadata(&name).expect("Unable to read metadata");
 
     let mut buffer = vec![0u8; metadata.len() as usize];
     // We pass &mut buffer to prevent changing the scope of buffer while still permitting modification
-    file.read(&mut buffer).expect("Buffer overflow");
+    match file.read(&mut buffer) {
+        Ok(_) => {},
+        _ => {
+            throw(BoronError::BufferOverflowError);
+            return BinConfig {program: Vec::new()};
+        }
+    };
 
     BinConfig {program: buffer}
 }
 
-pub fn txtconfigure() -> TxtConfig {
-    let args: Vec<String> = env::args().collect();
-    let name: String = args[1].clone();
-
-    // file must be mutable here as it is being read later in the program
-    // We also pass &name rather than name to prevent changing the parent scope of name
-    let mut file = fs::File::open(&name).expect("Could not find filename");
-
-    let mut buffer = String::new();
-    // We pass &mut buffer to prevent changing the scope of buffer while still permitting modification
-    file.read_to_string(&mut buffer).expect("Buffer overflow");
-
-    // Remove the extension from the name (so that we can put a .bex extension on it after assembly)
-    let mut name_ext_rmvd: String = name.clone();
-    name_ext_rmvd.truncate(name.len() - 4);
-
-    TxtConfig {program: buffer, name: name_ext_rmvd}
-}
-
-pub fn txtconfigure_from_filename(filename: &str) -> TxtConfig {
+pub fn txtconfigure(filename: &str) -> TxtConfig {
     let name: String = String::from(filename);
 
+    // Remove the extension from the name (so that we can put a .bex extension on it after assembly)
+    let split_by_dot: Vec<&str> = name.split(".").collect();
+    let len_split: usize = split_by_dot.len();
+    let name_ext_rmvd: String = String::from(split_by_dot[..len_split-1].join("."));
+
     // file must be mutable here as it is being read later in the program
     // We also pass &name rather than name to prevent changing the parent scope of name
-    let mut file = fs::File::open(&name).expect("Could not find filename");
+    let mut file = match fs::File::open(&name) {
+        Ok(f) => f,
+        _ => {
+            throw(BoronError::FileNotFoundError);
+            return TxtConfig {program: String::new(), name: name_ext_rmvd};
+        },
+    };
 
     let mut buffer = String::new();
     // We pass &mut buffer to prevent changing the scope of buffer while still permitting modification
-    file.read_to_string(&mut buffer).expect("Buffer overflow");
-
-    // Remove the extension from the name (so that we can put a .bex extension on it after assembly)
-    let name_ext_rmvd: String = name[..name.len()-4].to_string();
+    match file.read_to_string(&mut buffer) {
+        Ok(_) => {},
+        _ => {
+            throw(BoronError::BufferOverflowError);
+            return TxtConfig {program: String::new(), name: name_ext_rmvd};
+        }
+    };
 
     TxtConfig {program: buffer, name: name_ext_rmvd}
 }
\ No newline at end of file
